==> emodpy_converter-0.1.0-py3-none-any.whl: emodpy_converter/emodpy_converter_cli.py <==
import os
import argparse

from emodpy_converter.ask_llm import ask_llm, generate_retriever
from emodpy_converter.doc_loader import load_retrieval_documents
from emodpy_converter.secrets_loader import load_key
from emodpy_converter.template import extract_and_save_code, load_query


def get_json_paths(json_path):
    """Return a list of JSON file paths from a file or directory."""
    if os.path.isfile(json_path):
        return [json_path]
    if os.path.isdir(json_path):
        return [
            os.path.join(json_path, f)
            for f in os.listdir(json_path)
            if f.endswith('.json')
        ]
    raise ValueError("The provided json_path is neither a file nor a directory.")


def convert_json_file(json_path, docs, key_docs, split_docs, chroma_db_path, num_docs, openai_api_key, output_folder, model):
    """Process a single JSON file and save the generated code."""
    query = load_query(json_path)
    vector_db_fusion, dense_retriever = generate_retriever(
        chroma_db_path, docs, key_docs, num_docs, openai_api_key, query, split_docs
    )
    response, _, _ = ask_llm(openai_api_key, query, dense_retriever, vector_db_fusion, model=model)
    os.makedirs(output_folder, exist_ok=True)
    output_filename = os.path.basename(json_path).replace(".json", ".py")
    extract_and_save_code(response["result"], os.path.join(output_folder, output_filename))


def main():
    parser = argparse.ArgumentParser(description="Convert campaign JSON to Emodpy script using LLM and RAG.")
    parser.add_argument('-j', '--json_path', type=str, default="emodpy_converter/input/seed_infection_loop.json",
                        help='Path to a JSON file or directory containing JSON files. Default is ./input/seed_infection_loop.json.')
    parser.add_argument('-d', '--docs_path', type=str, default="emodpy_converter/Docs",
                        help='Path to the folder containing document files. Default is ./Docs.')
    parser.add_argument('-k', '--key_docs_path', type=str, default="emodpy_converter/Docs/key_docs",
                        help='Path to the folder containing key document files. Default is ./Docs/key_docs.')
    parser.add_argument('-s', '--split_docs_path', type=str, default="emodpy_converter/Docs/split_docs",
                        help='Path to the folder containing optional or large document files. Default is ./Docs/split_docs.')
    parser.add_argument('-m', '--model', type=str, default="o3-mini-2025-01-31",
                        help='OpenAI model to use for LLM queries. Options include \'o3-mini-2025-01-31\', '
                             '\'gpt-4o-2024-08-06\', \'gpt-4.1-2025-04-14\'. Default is \'o3-mini-2025-01-31\'.')
    parser.add_argument('-o', '--output', type=str, default="emodpy_converter/output",
                        help='Path to the folder where generated code is saved. Default is \'emodpy_converter/output\'.')
    parser.add_argument('-n', '--num_docs', type=int, default=12,
                        help='Number of documents to retrieve in addition to the key docs. Default is 12.')
    args = parser.parse_args()

    # Load the OpenAI API key from the secrets file, if it exists. Otherwise, read from en.
    if os.path.exists("keys.env"):
        openai_api_key = load_key(key_file="keys.env")
    else:
        openai_api_key = os.getenv("OPENAI_API_KEY")
    docs, key_docs, split_docs = load_retrieval_documents(args.docs_path, args.key_docs_path, args.split_docs_path)
    chroma_db_path = './chroma_db'
    output_folder = args.output
    model_name = args.model
    json_paths = get_json_paths(args.json_path)
    for path in json_paths:
        convert_json_file(path, docs, key_docs, split_docs, chroma_db_path, args.num_docs, openai_api_key, output_folder, model_name)


if __name__ == "__main__":
    main()

==> emodpy_converter-0.1.1-py3-none-any.whl: emodpy_converter/emodpy_converter_cli.py <==
import os
import argparse

from emodpy_converter.ask_llm import ask_llm, generate_retriever
from emodpy_converter.doc_loader import load_retrieval_documents
from emodpy_converter.secrets_loader import load_key
from emodpy_converter.template import extract_and_save_code, load_query


def get_json_paths(json_path):
    """Return a list of JSON file paths from a file or directory."""
    if os.path.isfile(json_path):
        return [json_path]
    if os.path.isdir(json_path):
        return [
            os.path.join(json_path, f)
            for f in os.listdir(json_path)
            if f.endswith('.json')
        ]
    raise ValueError("The provided json_path is neither a file nor a directory.")


def convert_json_file(json_path, docs, key_docs, split_docs, chroma_db_path, num_docs, openai_api_key, output_folder, model):
    """Process a single JSON file and save the generated code."""
    query = load_query(json_path)
    vector_db_fusion, dense_retriever = generate_retriever(
        chroma_db_path, docs, key_docs, num_docs, openai_api_key, query, split_docs
    )
    response, _, _ = ask_llm(openai_api_key, query, dense_retriever, vector_db_fusion, model=model)
    os.makedirs(output_folder, exist_ok=True)
    output_filename = os.path.basename(json_path).replace(".json", ".py")
    extract_and_save_code(response["result"], os.path.join(output_folder, output_filename))


def main():
    parser = argparse.ArgumentParser(description="Convert campaign JSON to Emodpy script using LLM and RAG.")
    parser.add_argument('-j', '--json_path', type=str, default="./emodpy_converter/input/seed_infection_loop.json",
                        help='Path to a JSON file or directory containing JSON files. Default is ./emodpy_converter/input/seed_infection_loop.json.')
    parser.add_argument('-d', '--docs_path', type=str, default="./emodpy_converter/Docs",
                        help='Path to the folder containing document files. Default is ./emodpy_converter/Docs.')
    parser.add_argument('-k', '--key_docs_path', type=str, default="./emodpy_converter/Docs/key_docs",
                        help='Path to the folder containing key document files. Default is ./emodpy_converter/Docs/key_docs.')
    parser.add_argument('-s', '--split_docs_path', type=str, default="./emodpy_converter/Docs/split_docs",
                        help='Path to the folder containing optional or large document files. Default is ./emodpy_converter/Docs/split_docs.')
    parser.add_argument('-m', '--model', type=str, default="o3-mini-2025-01-31",
                        help='OpenAI model to use for LLM queries. Options include \'o3-mini-2025-01-31\', '
                             '\'gpt-4o-2024-08-06\', \'gpt-4.1-2025-04-14\'. Default is \'o3-mini-2025-01-31\'.')
    parser.add_argument('-o', '--output', type=str, default="./emodpy_converter/output",
                        help='Path to the folder where generated code is saved. Default is ./emodpy_converter/output.')
    parser.add_argument('-n', '--num_docs', type=int, default=12,
                        help='Number of documents to retrieve in addition to the key docs. Default is 12.')
    args = parser.parse_args()

    # Load the OpenAI API key from the secrets file, if it exists. Otherwise, read from en.
    if os.path.exists("keys.env"):
        openai_api_key = load_key(key_file="keys.env")
    else:
        openai_api_key = os.getenv("OPENAI_API_KEY")
    docs, key_docs, split_docs = load_retrieval_documents(args.docs_path, args.key_docs_path, args.split_docs_path)
    chroma_db_path = './chroma_db'
    output_folder = args.output
    model_name = args.model
    json_paths = get_json_paths(args.json_path)
    for path in json_paths:
        convert_json_file(path, docs, key_docs, split_docs, chroma_db_path, args.num_docs, openai_api_key, output_folder, model_name)


if __name__ == "__main__":
    main()
